# Generated by Django 2.0.2 on 2018-03-23 16:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('telegram_bots', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='authorization',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='authorizations', to='telegram_bots.TelegramUser'),
        ),
    ]
